@@ -1,8 +1,8 @@
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 
-/* Copyright (C) 2018-2022 Hans Petter Jansson
+/* Copyright (C) 2018-2025 Hans Petter Jansson
  *
- * This file is part of Chafa, a program that turns images into character art.
+ * This file is part of Chafa, a program that shows pictures on text terminals.
  *
  * Chafa is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published
@@ -28,85 +28,6 @@
 
 G_BEGIN_DECLS
 
-/* Color extractor */
-
-typedef enum
-{
-    CHAFA_COLOR_EXTRACTOR_AVERAGE,
-    CHAFA_COLOR_EXTRACTOR_MEDIAN,
-
-    CHAFA_COLOR_EXTRACTOR_MAX
-}
-ChafaColorExtractor;
-
-/* Color spaces */
-
-typedef enum
-{
-    CHAFA_COLOR_SPACE_RGB,
-    CHAFA_COLOR_SPACE_DIN99D,
-
-    CHAFA_COLOR_SPACE_MAX
-}
-ChafaColorSpace;
-
-/* Canvas modes */
-
-typedef enum
-{
-    CHAFA_CANVAS_MODE_TRUECOLOR,
-    CHAFA_CANVAS_MODE_INDEXED_256,
-    CHAFA_CANVAS_MODE_INDEXED_240,
-    CHAFA_CANVAS_MODE_INDEXED_16,
-    CHAFA_CANVAS_MODE_FGBG_BGFG,
-    CHAFA_CANVAS_MODE_FGBG,
-    CHAFA_CANVAS_MODE_INDEXED_8,
-    CHAFA_CANVAS_MODE_INDEXED_16_8,
-
-    CHAFA_CANVAS_MODE_MAX
-}
-ChafaCanvasMode;
-
-/* Dither modes */
-
-typedef enum
-{
-    CHAFA_DITHER_MODE_NONE,
-    CHAFA_DITHER_MODE_ORDERED,
-    CHAFA_DITHER_MODE_DIFFUSION,
-
-    CHAFA_DITHER_MODE_MAX
-}
-ChafaDitherMode;
-
-/* Pixel modes */
-
-typedef enum
-{
-    CHAFA_PIXEL_MODE_SYMBOLS,
-    CHAFA_PIXEL_MODE_SIXELS,
-    CHAFA_PIXEL_MODE_KITTY,
-    CHAFA_PIXEL_MODE_ITERM2,
-
-    CHAFA_PIXEL_MODE_MAX
-}
-ChafaPixelMode;
-
-/* Sequence optimization flags. When enabled, these may produce more compact
- * output at the cost of reduced compatibility and increased CPU use. Output
- * quality is unaffected. */
-
-typedef enum
-{
-    CHAFA_OPTIMIZATION_REUSE_ATTRIBUTES = (1 << 0),
-    CHAFA_OPTIMIZATION_SKIP_CELLS = (1 << 1),
-    CHAFA_OPTIMIZATION_REPEAT_CELLS = (1 << 2),
-
-    CHAFA_OPTIMIZATION_NONE = 0,
-    CHAFA_OPTIMIZATION_ALL = 0x7fffffff
-}
-ChafaOptimizations;
-
 /* Canvas config */
 
 typedef struct ChafaCanvasConfig ChafaCanvasConfig;
@@ -210,6 +131,11 @@ gboolean chafa_canvas_config_get_fg_only_enabled (const ChafaCanvasConfig *confi
 CHAFA_AVAILABLE_IN_1_8
 void chafa_canvas_config_set_fg_only_enabled (ChafaCanvasConfig *config, gboolean fg_only_enabled);
 
+CHAFA_AVAILABLE_IN_1_14
+ChafaPassthrough chafa_canvas_config_get_passthrough (const ChafaCanvasConfig *config);
+CHAFA_AVAILABLE_IN_1_14
+void chafa_canvas_config_set_passthrough (ChafaCanvasConfig *config, ChafaPassthrough passthrough);
+
 G_END_DECLS
 
 #endif /* __CHAFA_CANVAS_CONFIG_H__ */
