@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 
-/* Copyright (C) 2019-2023 Hans Petter Jansson
+/* Copyright (C) 2019-2025 Hans Petter Jansson
  *
  * This file is part of Chafa, a program that shows pictures on text terminals.
  *
@@ -40,6 +40,7 @@ G_BEGIN_DECLS
 #define CHAFA_VERSION_1_10 (G_ENCODE_VERSION (1, 10))
 #define CHAFA_VERSION_1_12 (G_ENCODE_VERSION (1, 12))
 #define CHAFA_VERSION_1_14 (G_ENCODE_VERSION (1, 14))
+#define CHAFA_VERSION_1_16 (G_ENCODE_VERSION (1, 16))
 
 /* Evaluates to the current stable version; for development cycles,
  * this means the next stable target. */
@@ -231,6 +232,20 @@ G_BEGIN_DECLS
 # define CHAFA_AVAILABLE_IN_1_14                _CHAFA_EXTERN
 #endif
 
+#if CHAFA_VERSION_MIN_REQUIRED >= CHAFA_VERSION_1_16
+# define CHAFA_DEPRECATED_IN_1_16               G_DEPRECATED
+# define CHAFA_DEPRECATED_IN_1_16_FOR(f)        G_DEPRECATED_FOR(f)
+#else
+# define CHAFA_DEPRECATED_IN_1_16               _CHAFA_EXTERN
+# define CHAFA_DEPRECATED_IN_1_16_FOR(f)        _CHAFA_EXTERN
+#endif
+
+#if CHAFA_VERSION_MAX_ALLOWED < CHAFA_VERSION_1_16
+# define CHAFA_AVAILABLE_IN_1_16                G_UNAVAILABLE(1, 16)
+#else
+# define CHAFA_AVAILABLE_IN_1_16                _CHAFA_EXTERN
+#endif
+
 G_END_DECLS
 
 #endif /* __CHAFA_VERSION_MACROS_H__ */
